function overlaps = overlap(w,a,M,s,f,N)
%   For each useful window, compute the number of its samples overlapping with the gap .
%
%   Usage:  overlaps = overlap(w,a,M,s,f,N);
%
%   Input parameters:
%         w     : Window length.
%         a     : Length of time shift.
%         M     : Number of modulations.
%         s     : Left edge index of the gap.
%         f     : Right edge index of the gap.
%         N     : Signal length.
%         
%   Output parameters:
%   overlaps    : vector with the numbers of overlapping samples for each
%                 useful window
%                 ("useful" means non-empty overlap with the gap)

% (c) 2015 Hana Bartlov, Pavel Rajmic, Brno University of Technology,
% Czech Republic

% make artificial signal (ones in the gap)
sig=zeros(N,1);
sig(s:f)=1;

% perform DGT with rectangular window to get the desired numbers
g=ones(w,1);
c=dgtreal(sig,g,a,M);

overlaps=c(1,:); % just the DC component
overlaps=overlaps(~~overlaps); %select and output just the non-zero values